(|9| |8| |7| |6| |5| |4| |3| |2| |1| |0| $)
(digits digit digitsp)
(
((|9| digits) (digit digitsp))
((|8| digits) (digit digitsp))
((|7| digits) (digit digitsp))
((|6| digits) (digit digitsp))
((|5| digits) (digit digitsp))
((|4| digits) (digit digitsp))
((|3| digits) (digit digitsp))
((|2| digits) (digit digitsp))
((|1| digits) (digit digitsp))
((|0| digits) (digit digitsp))
((|0| digit) (|0|))
((|1| digit) (|1|))
((|2| digit) (|2|))
((|3| digit) (|3|))
((|4| digit) (|4|))
((|5| digit) (|5|))
((|6| digit) (|6|))
((|7| digit) (|7|))
((|8| digit) (|8|))
((|9| digit) (|9|))
((|9| digitsp) (digits))
((|8| digitsp) (digits))
((|7| digitsp) (digits))
((|6| digitsp) (digits))
((|5| digitsp) (digits))
((|4| digitsp) (digits))
((|3| digitsp) (digits))
((|2| digitsp) (digits))
((|1| digitsp) (digits))
((|0| digitsp) (digits))
(($ digitsp) ())
)
